summaryrefslogtreecommitdiffstats
path: root/src/include/usr
diff options
context:
space:
mode:
authorBrian Horton <brianh@linux.ibm.com>2013-07-16 16:43:59 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-07-17 14:45:51 -0500
commit9b0ba036719a1c14a9be384bdf214527dbcbfb71 (patch)
treef209eab434a1e00a8bb1fe7e028fb818e9a2ae95 /src/include/usr
parent8347820de97d4e197e716646c5a3a98c8169a41e (diff)
downloadtalos-hostboot-9b0ba036719a1c14a9be384bdf214527dbcbfb71.tar.gz
talos-hostboot-9b0ba036719a1c14a9be384bdf214527dbcbfb71.zip
change i_errl parameter in processCallout() for fsp
fsp code might change the errl (ie, on abort) so this needs to be a reference so that the new log works it's way back up. Change-Id: I08c7760cb77a7577d1c7017362503c08d5f1e829 RTC: 69461 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/5430 Tested-by: Jenkins Server Reviewed-by: Nicholas E. Bofferding <bofferdn@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/usr')
-rw-r--r--src/include/usr/hwas/common/hwasCallout.H18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/include/usr/hwas/common/hwasCallout.H b/src/include/usr/hwas/common/hwasCallout.H
index 91232dc0b..932250a97 100644
--- a/src/include/usr/hwas/common/hwasCallout.H
+++ b/src/include/usr/hwas/common/hwasCallout.H
@@ -143,25 +143,25 @@ typedef struct callout_ud
* @brief processCallout process the userdetail for a callout, calling
* the deconfigure and/or GARD funcationality as appropriate
*
* @param[in] i_errl Error log handle
* @param[in] i_pData Pointer to the callout bundle
* @param[in] i_Size size of the data in the callout bundle
* @param[in] i_DeferredOnly bool - true if ONLY check for defered deconfig
*
*/
-void processCallout(errlHndl_t i_errl,
+void processCallout(errlHndl_t &io_errl,
uint8_t *i_pData,
uint64_t i_Size,
bool i_DeferredOnly = false);
// typedef for function pointer that the errlog class will use.
-typedef bool (*processCalloutFn)(errlHndl_t, uint8_t *, uint64_t, bool);
+typedef bool (*processCalloutFn)(errlHndl_t &, uint8_t *, uint64_t, bool);
/**
* @brief platform specific code to handle a procedure callout that has been
* found in an errlog
*
* @param[in] i_errl errlHndl for this errlog.
* @param[in] i_procedure Enum indicating which procedure to add to the
* error log
* @param[in] i_priority Enum indicating the priority of the callout
@@ -169,7 +169,7 @@ typedef bool (*processCalloutFn)(errlHndl_t, uint8_t *, uint64_t, bool);
* @return errlHndl_t valid errlHndl_t handle if there was an error,
* NULL if no errors;
*/
-errlHndl_t platHandleProcedureCallout(errlHndl_t i_errl,
+errlHndl_t platHandleProcedureCallout(errlHndl_t &io_errl,
epubProcedureID i_procedure,
callOutPriority i_priority);
@@ -180,7 +180,7 @@ errlHndl_t platHandleProcedureCallout(errlHndl_t i_errl,
* @param[in] i_pTarget target
* @param[in] i_priority Enum indicating the priority of the callout
* @param[in] i_deconfigState Enum indicating whether to deconfig or not
* @param[in] i_errl errlHnld for this errlog
* @param[in] i_gardErrType Enum indicating the type of failure
*
* @return errlHndl_t valid errlHndl_t handle if there was an error,
@@ -190,7 +190,7 @@ errlHndl_t platHandleHWCallout(
TARGETING::Target *i_pTarget,
callOutPriority i_priority,
DeconfigEnum i_deconfigState,
- errlHndl_t i_errl,
+ errlHndl_t &io_errl,
GARD_ErrorType i_gardErrorType);
/**
@@ -201,7 +201,7 @@ errlHndl_t platHandleHWCallout(
* @param[in] i_pTarget2 target endpoint2
* @param[in] i_busType bus type Enum
* @param[in] i_priority Enum indicating the priority of the callout
* @param[in] i_errl errlHnld for this errlog
*
* @return errlHndl_t valid errlHndl_t handle if there was an error,
* NULL if no errors;
@@ -211,7 +211,7 @@ errlHndl_t platHandleBusCallout(
TARGETING::Target *i_pTarget2,
busTypeEnum i_busType,
callOutPriority i_priority,
- errlHndl_t i_errl);
+ errlHndl_t &io_errl);
#endif // not PARSER
OpenPOWER on IntegriCloud
@@ -143,25 +143,25 @@ typedef struct callout_ud
* the deconfigure and/or GARD funcationality as appropriate
*
- * @param[in] i_errl Error log handle
+ * @param[in] io_errl Error log handle reference
* @param[in] i_pData Pointer to the callout bundle
* @param[in] i_Size size of the data in the callout bundle
@@ -143,25 +143,25 @@ typedef struct callout_ud
* found in an errlog
*
- * @param[in] i_errl errlHndl for this errlog.
+ * @param[in] io_errl reference to errlHndl for this errlog.
* @param[in] i_procedure Enum indicating which procedure to add to the
* error log
@@ -180,7 +180,7 @@ errlHndl_t platHandleProcedureCallout(errlHndl_t i_errl,
* @param[in] i_priority Enum indicating the priority of the callout
* @param[in] i_deconfigState Enum indicating whether to deconfig or not
- * @param[in] i_errl errlHnld for this errlog
+ * @param[in] io_errl reference to errlHnld for this errlog
* @param[in] i_gardErrType Enum indicating the type of failure
*
@@ -201,7 +201,7 @@ errlHndl_t platHandleHWCallout(
* @param[in] i_busType bus type Enum
* @param[in] i_priority Enum indicating the priority of the callout
- * @param[in] i_errl errlHnld for this errlog
+ * @param[in] io_errl reference to errlHnld for this errlog
*
* @return errlHndl_t valid errlHndl_t handle if there was an error,